@@ -1,7 +1,6 @@
-from datetime import datetime
 import re
 import shutil
-from typing import List
+from typing import List, Optional
 from cli_tools_info.utils import Tool, run_cmd, success, fail
 import tabulate
 import asyncio
@@ -20,7 +19,7 @@ async def _process_output_of_cmd(tool: Tool) -> List[str]:
         return success(tool.name, output)
 
 
-async def _async_run(tools: List[Tool]):
+async def _async_run(tools: List[Tool], headers: bool, table_fmt: Optional[str]):
     async def inner(tool: Tool):
         if tool.use_which:
             which_output = shutil.which(tool.name)
@@ -32,10 +31,16 @@ async def _async_run(tools: List[Tool]):
             return await _process_output_of_cmd(tool)
 
     data = await asyncio.gather(*[inner(x) for x in tools])
-    print(tabulate.tabulate(tabular_data=data))
+    if headers:
+        tab_headers = ["CLI", "version"]
+    else:
+        tab_headers = []
+    if not table_fmt:
+        table_fmt = "simple"
+    print(tabulate.tabulate(tabular_data=data, headers=tab_headers, tablefmt=table_fmt))
 
 
-def run(tools: List[Tool]):
+def run(tools: List[Tool], headers: bool = False, table_fmt: Optional[str] = None):
     loop = asyncio.get_event_loop()
-    loop.run_until_complete(_async_run(tools=tools))
+    loop.run_until_complete(_async_run(tools=tools, headers=headers, table_fmt=table_fmt))
     loop.close()
